#!/usr/bin/env node
"use strict";
/**
 * CodeContext Memory Pro - Memory-Only Launch Version
 *
 * The AI memory revolution starts here.
 * $99/month for the first 10,000 early adopters.
 * Then $199/month forever.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const chalk_1 = __importDefault(require("chalk"));
const MemoryEngine_1 = require("./memory/MemoryEngine");
const ProjectScanner_1 = require("./memory/ProjectScanner");
const vscode_setup_1 = require("./integrations/vscode-setup");
const LicenseService_1 = require("./services/LicenseService");
const FirebaseService_1 = require("./services/FirebaseService");
const packageJson = __importStar(require("../package.json"));
const program = new commander_1.Command();
program
    .name('codecontext')
    .description('🧠 AI Memory Revolution - Stop AI amnesia forever')
    .version(packageJson.version)
    .addHelpText('before', `
${chalk_1.default.bold.cyan('🧠 CodeContext Memory Pro - AI Memory Revolution')}

${chalk_1.default.yellow('🔥 EARLY ADOPTER SPECIAL: $99/month FOREVER (First 10,000 licenses)')}
${chalk_1.default.yellow('📈 After 10,000 sold: $199/month')}

Give your AI assistant PERSISTENT MEMORY across ALL sessions.
The most revolutionary productivity upgrade since the IDE was invented.
  `);
// Purchase command
program
    .command('purchase')
    .description('🔥 Purchase your memory revolution license')
    .argument('<email>', 'Your email address')
    .action(async (email) => {
    try {
        console.log(chalk_1.default.bold.cyan('\n🧠 Welcome to the AI Memory Revolution!\n'));
        const licenseKey = await LicenseService_1.licenseService.purchaseLicense(email);
        console.log(chalk_1.default.green('\n🎉 License purchased!'));
        console.log(chalk_1.default.blue(`\nNext step: codecontext activate ${email} ${licenseKey}`));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Purchase failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Activate command
program
    .command('activate')
    .description('🚀 Activate your memory revolution license')
    .argument('<email>', 'Your email address')
    .argument('<license-key>', 'Your license key')
    .action(async (email, licenseKey) => {
    try {
        await LicenseService_1.licenseService.activateLicense(email, licenseKey);
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Activation failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// License status
program
    .command('license')
    .description('📊 Show license status')
    .action(async () => {
    try {
        await LicenseService_1.licenseService.showLicenseStatus();
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to get license status:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Protected commands (require license)
async function requireLicense() {
    const license = await LicenseService_1.licenseService.getCurrentLicense();
    if (!license) {
        console.log(chalk_1.default.red(`
🔒 MEMORY REVOLUTION LICENSE REQUIRED

This feature requires CodeContext Memory Pro.

🔥 Early Adopter Special: $99/month FOREVER
📈 After 10,000 licenses: $199/month

Your AI assistant is stuck with amnesia until activated.
Purchase now: codecontext purchase your@email.com
    `));
        process.exit(1);
    }
    return license;
}
program
    .command('init')
    .description('🧠 Initialize persistent AI memory for current project')
    .option('-f, --force', 'Force reinitialize existing project')
    .action(async (options) => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('persistentMemory');
        const memory = new MemoryEngine_1.MemoryEngine();
        await memory.initProject(process.cwd(), options.force);
        // Report usage
        await FirebaseService_1.firebaseService.reportUsage('project_init', {
            projectPath: process.cwd(),
            forced: options.force
        });
        console.log(chalk_1.default.green('🧠 AI Memory initialized! Your assistant will REMEMBER EVERYTHING.'));
        console.log(chalk_1.default.blue('💡 Your AI now has persistent memory across ALL sessions'));
        console.log(chalk_1.default.blue('💡 Run "codecontext status" to see memory state'));
        console.log(chalk_1.default.blue('💡 Run "codecontext scan --deep" for advanced analysis'));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to initialize:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('status')
    .description('📊 Show AI memory status')
    .action(async () => {
    try {
        await requireLicense();
        const memory = new MemoryEngine_1.MemoryEngine();
        const status = await memory.getProjectStatus(process.cwd());
        console.log(chalk_1.default.bold('\n🧠 CodeContext Memory Pro - AI Memory Status\n'));
        console.log(`📂 Project: ${chalk_1.default.cyan(status.projectName)}`);
        console.log(`🆔 ID: ${status.projectId}`);
        console.log(`📅 Created: ${status.createdAt.toLocaleString()}`);
        console.log(`🕐 Last Active: ${status.lastActive.toLocaleString()}`);
        console.log(`📁 Files Tracked: ${chalk_1.default.yellow(status.filesTracked.toString())}`);
        console.log(`💬 Conversations: ${chalk_1.default.yellow(status.conversations.toString())}`);
        console.log(`🧩 Patterns: ${chalk_1.default.yellow(status.patterns.toString())}`);
        console.log(`📊 Memory Size: ${status.memorySize}`);
        if (status.recentActivity.length > 0) {
            console.log(chalk_1.default.bold('\n📈 Recent Memory Activity:'));
            status.recentActivity.forEach(activity => {
                console.log(`  • ${activity.timestamp.toLocaleString()}: ${activity.description}`);
            });
        }
        console.log(chalk_1.default.green('\n✅ Your AI has persistent memory! No more amnesia.'));
        await FirebaseService_1.firebaseService.reportUsage('status_check');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to get status:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('scan')
    .description('🔍 Scan and analyze project for persistent memory')
    .option('-d, --deep', 'Perform deep pattern analysis')
    .action(async (options) => {
    try {
        const license = await requireLicense();
        // SECURITY: Validate usage before operation
        try {
            const usageResult = await FirebaseService_1.firebaseService.validateUsage('scan', license.email, license.id);
            console.log(chalk_1.default.dim(`💡 Usage: ${usageResult.remaining}/${usageResult.limit} remaining (${usageResult.tier})`));
        }
        catch (error) {
            console.error(chalk_1.default.red('❌ Usage limit exceeded:'), error instanceof Error ? error.message : error);
            console.log(chalk_1.default.yellow('\n🔥 Upgrade to get more operations: https://codecontextpro.com'));
            process.exit(1);
        }
        const memory = new MemoryEngine_1.MemoryEngine();
        const scanner = new ProjectScanner_1.ProjectScanner();
        console.log(chalk_1.default.blue('🔍 Scanning project for persistent memory storage...'));
        const analysis = await scanner.scanProject(process.cwd(), options.deep);
        await memory.storeProjectAnalysis(process.cwd(), analysis);
        console.log(chalk_1.default.green(`✅ Stored ${analysis.files.length} files in AI memory`));
        console.log(chalk_1.default.blue(`🧩 Discovered ${analysis.patterns.length} code patterns`));
        console.log(chalk_1.default.blue(`🏗️ Detected ${analysis.architecture.frameworks.length} frameworks`));
        console.log(chalk_1.default.cyan('🧠 Your AI will remember all of this forever!'));
        await FirebaseService_1.firebaseService.reportUsage('project_scan', {
            filesScanned: analysis.files.length,
            patternsFound: analysis.patterns.length,
            deepScan: options.deep
        });
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to scan:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('remember')
    .description('🧠 Store something in AI memory forever')
    .argument('<content>', 'What your AI should remember')
    .option('-t, --type <type>', 'Memory type (conversation, decision, pattern)', 'conversation')
    .option('-c, --context <context>', 'Additional context')
    .action(async (content, options) => {
    try {
        const license = await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('persistentMemory');
        // SECURITY: Validate usage before operation
        try {
            const usageResult = await FirebaseService_1.firebaseService.validateUsage('remember', license.email, license.id);
            console.log(chalk_1.default.dim(`💡 Usage: ${usageResult.remaining}/${usageResult.limit} remaining (${usageResult.tier})`));
        }
        catch (error) {
            console.error(chalk_1.default.red('❌ Usage limit exceeded:'), error instanceof Error ? error.message : error);
            console.log(chalk_1.default.yellow('\n🔥 Upgrade to get more operations: https://codecontextpro.com'));
            process.exit(1);
        }
        const memory = new MemoryEngine_1.MemoryEngine();
        await memory.storeMemory(process.cwd(), {
            type: options.type,
            content,
            context: options.context,
            timestamp: new Date()
        });
        await FirebaseService_1.firebaseService.reportUsage('memory_store', {
            type: options.type,
            contentLength: content.length
        });
        console.log(chalk_1.default.green('🧠 Memory stored! Your AI will remember this FOREVER.'));
        console.log(chalk_1.default.blue('💡 No more explaining the same context over and over'));
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to store memory:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('recall')
    .description('🔍 Search AI memory')
    .argument('[query]', 'Search query')
    .option('-t, --type <type>', 'Filter by memory type')
    .option('-l, --limit <limit>', 'Limit number of results', '10')
    .action(async (query, options) => {
    try {
        const license = await requireLicense();
        // SECURITY: Validate usage before operation
        try {
            const usageResult = await FirebaseService_1.firebaseService.validateUsage('recall', license.email, license.id);
            console.log(chalk_1.default.dim(`💡 Usage: ${usageResult.remaining}/${usageResult.limit} remaining (${usageResult.tier})`));
        }
        catch (error) {
            console.error(chalk_1.default.red('❌ Usage limit exceeded:'), error instanceof Error ? error.message : error);
            console.log(chalk_1.default.yellow('\n🔥 Upgrade to get more operations: https://codecontextpro.com'));
            process.exit(1);
        }
        const memory = new MemoryEngine_1.MemoryEngine();
        const results = await memory.searchMemories(process.cwd(), query, {
            type: options.type,
            limit: parseInt(options.limit)
        });
        if (results.length === 0) {
            console.log(chalk_1.default.yellow('🤔 No memories found'));
            return;
        }
        console.log(chalk_1.default.bold(`\n🧠 Your AI remembers ${results.length} things:\n`));
        results.forEach((memory, index) => {
            console.log(chalk_1.default.cyan(`${index + 1}. [${memory.type}] ${memory.timestamp.toLocaleDateString()}`));
            console.log(`   ${memory.content}`);
            if (memory.context) {
                console.log(chalk_1.default.gray(`   Context: ${memory.context}`));
            }
            console.log();
        });
        console.log(chalk_1.default.green('✅ This is the power of persistent AI memory!'));
        await FirebaseService_1.firebaseService.reportUsage('memory_recall', {
            query: query || 'all',
            resultsFound: results.length
        });
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to recall memories:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('sync')
    .description('☁️ Sync memory to cloud')
    .action(async () => {
    try {
        await requireLicense();
        await LicenseService_1.licenseService.validateFeatureAccess('cloudSync');
        console.log(chalk_1.default.blue('☁️ Syncing memory to cloud...'));
        // Implementation would sync local memory to Firebase
        console.log(chalk_1.default.green('✅ Memory synced! Available on all your devices.'));
        await FirebaseService_1.firebaseService.reportUsage('cloud_sync');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Sync failed:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
program
    .command('export')
    .description('📤 Export AI memory to file')
    .option('-f, --format <format>', 'Export format (json, markdown)', 'json')
    .option('-o, --output <file>', 'Output file path')
    .action(async (options) => {
    try {
        const license = await requireLicense();
        // SECURITY: Validate usage before operation
        try {
            const usageResult = await FirebaseService_1.firebaseService.validateUsage('export', license.email, license.id);
            console.log(chalk_1.default.dim(`💡 Usage: ${usageResult.remaining}/${usageResult.limit} remaining (${usageResult.tier})`));
        }
        catch (error) {
            console.error(chalk_1.default.red('❌ Usage limit exceeded:'), error instanceof Error ? error.message : error);
            console.log(chalk_1.default.yellow('\n🔥 Upgrade to get more operations: https://codecontextpro.com'));
            process.exit(1);
        }
        const memory = new MemoryEngine_1.MemoryEngine();
        const data = await memory.exportMemory(process.cwd(), options.format);
        const filename = options.output || `ai-memory.${options.format}`;
        await require('fs-extra').writeFile(filename, data);
        console.log(chalk_1.default.green(`✅ AI memory exported to ${filename}`));
        console.log(chalk_1.default.blue('💡 Share this with your team or use for documentation'));
        await FirebaseService_1.firebaseService.reportUsage('memory_export', {
            format: options.format,
            filename
        });
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to export memory:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// VS Code integration (premium feature)
program
    .command('vscode')
    .description('🔧 Set up VS Code integration')
    .action(async () => {
    try {
        await requireLicense();
        await (0, vscode_setup_1.setupVSCode)(process.cwd());
        console.log(chalk_1.default.green('✅ VS Code integration configured!'));
        console.log(chalk_1.default.blue('💡 Restart VS Code to activate memory features'));
        console.log(chalk_1.default.cyan('🧠 Your AI now has memory in VS Code too!'));
        await FirebaseService_1.firebaseService.reportUsage('vscode_setup');
    }
    catch (error) {
        console.error(chalk_1.default.red('❌ Failed to set up VS Code:'), error instanceof Error ? error.message : error);
        process.exit(1);
    }
});
// Show help if no command provided
program.parse();
if (!process.argv.slice(2).length) {
    console.log(chalk_1.default.bold.cyan('\n🧠 CodeContext Memory Pro - AI Memory Revolution\n'));
    console.log(chalk_1.default.yellow('🔥 EARLY ADOPTER SPECIAL: $99/month FOREVER (First 10,000 licenses)'));
    console.log(chalk_1.default.yellow('📈 After 10,000 sold: $199/month\n'));
    program.outputHelp();
    console.log(chalk_1.default.blue('\n💡 Start the memory revolution:'));
    console.log(chalk_1.default.blue('   codecontext purchase your@email.com'));
    console.log(chalk_1.default.blue('   codecontext activate your@email.com YOUR-LICENSE-KEY'));
    console.log(chalk_1.default.blue('   codecontext init'));
    console.log(chalk_1.default.cyan('\n🧠 What you get:'));
    console.log(chalk_1.default.cyan('   ✅ Persistent AI memory across ALL sessions'));
    console.log(chalk_1.default.cyan('   ✅ Never explain context again'));
    console.log(chalk_1.default.cyan('   ✅ AI remembers your decisions forever'));
    console.log(chalk_1.default.cyan('   ✅ Cloud sync across devices'));
    console.log(chalk_1.default.cyan('   ✅ VS Code integration'));
    console.log(chalk_1.default.gray('\n💰 Compare:'));
    console.log(chalk_1.default.gray('   ❌ ChatGPT Pro: $20/month (no memory)'));
    console.log(chalk_1.default.gray('   ❌ Claude Pro: $20/month (no memory)'));
    console.log(chalk_1.default.gray('   ✅ CodeContext Memory Pro: $99/month (INFINITE MEMORY)'));
    console.log(chalk_1.default.yellow('\n🚀 This memory upgrade pays for itself in 1 day.'));
    console.log(chalk_1.default.yellow('💎 Join the AI memory revolution!'));
}
//# sourceMappingURL=cli-memory-only.js.map