"use strict";
/**
 * VS Code Integration - No extension required
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.VSCodeIntegration = void 0;
const path = __importStar(require("path"));
const fs = __importStar(require("fs-extra"));
const MemoryEngine_1 = require("../memory/MemoryEngine");
class VSCodeIntegration {
    constructor() {
        this.memory = new MemoryEngine_1.MemoryEngine();
    }
    async getFileContext(filePath, line = undefined) {
        const projectPath = this.findProjectRoot(filePath);
        try {
            const projectMemory = await this.memory.getProjectStatus(projectPath);
            // Get related patterns for this file
            const relatedPatterns = await this.getFilePatterns(projectPath, filePath);
            // Get recent memories that might be relevant
            const recentMemories = await this.memory.searchMemories(projectPath, undefined, { limit: 5 });
            // Generate context-aware suggestions
            const suggestions = await this.generateSuggestions(filePath, line, relatedPatterns);
            return {
                file: filePath,
                line,
                projectMemory,
                relatedPatterns,
                recentMemories,
                suggestions
            };
        }
        catch (error) {
            // If project not initialized, return minimal context
            return {
                file: filePath,
                line,
                projectMemory: {
                    projectId: '',
                    projectName: path.basename(projectPath),
                    createdAt: new Date(),
                    lastActive: new Date(),
                    filesTracked: 0,
                    conversations: 0,
                    patterns: 0,
                    memorySize: '0 B',
                    recentActivity: []
                },
                relatedPatterns: [],
                recentMemories: [],
                suggestions: ['Run "codecontext init" to enable memory for this project']
            };
        }
    }
    findProjectRoot(filePath) {
        let dir = path.dirname(filePath);
        while (dir !== path.dirname(dir)) {
            // Check for common project indicators
            const indicators = [
                'package.json',
                'Cargo.toml',
                'go.mod',
                'requirements.txt',
                '.git',
                '.codecontext'
            ];
            for (const indicator of indicators) {
                if (fs.existsSync(path.join(dir, indicator))) {
                    return dir;
                }
            }
            dir = path.dirname(dir);
        }
        return path.dirname(filePath);
    }
    async getFilePatterns(projectPath, filePath) {
        // This would query the database for patterns related to this file
        // For now, return empty array
        return [];
    }
    async generateSuggestions(filePath, line, patterns) {
        const suggestions = [];
        const ext = path.extname(filePath);
        // Language-specific suggestions
        switch (ext) {
            case '.js':
            case '.jsx':
                suggestions.push('Consider adding JSDoc comments for better documentation');
                suggestions.push('Use const/let instead of var for better scoping');
                break;
            case '.ts':
            case '.tsx':
                suggestions.push('Add explicit type annotations for better type safety');
                suggestions.push('Consider using interfaces for object shapes');
                break;
            case '.py':
                suggestions.push('Add type hints for better code documentation');
                suggestions.push('Follow PEP 8 style guidelines');
                break;
            case '.rs':
                suggestions.push('Consider using Result<T, E> for error handling');
                suggestions.push('Add documentation comments with ///');
                break;
        }
        // Pattern-based suggestions
        if (patterns.length > 0) {
            suggestions.push(`Found ${patterns.length} similar patterns in your codebase`);
        }
        // Context-aware suggestions based on file name
        if (filePath.includes('test')) {
            suggestions.push('Consider adding more test cases for edge conditions');
            suggestions.push('Ensure tests are independent and can run in any order');
        }
        if (filePath.includes('config')) {
            suggestions.push('Consider using environment variables for sensitive data');
            suggestions.push('Add validation for configuration values');
        }
        return suggestions;
    }
}
exports.VSCodeIntegration = VSCodeIntegration;
//# sourceMappingURL=VSCodeIntegration.js.map