/**
 * Firebase Backend Service
 * Handles authentication, licensing, and cloud memory sync
 */
export interface License {
    id: string;
    userId: string;
    email: string;
    tier: 'early_adopter' | 'standard';
    price: number;
    activatedAt: Date;
    expiresAt: Date;
    status: 'active' | 'expired' | 'suspended';
    maxProjects: number;
    features: {
        persistentMemory: boolean;
        executionEngine: boolean;
        cloudSync: boolean;
        multiProject: boolean;
        prioritySupport: boolean;
    };
}
export interface EarlyAdopterStats {
    totalSold: number;
    remaining: number;
    currentPrice: number;
    nextPrice: number;
}
export declare class FirebaseService {
    private baseUrl;
    private apiKey?;
    constructor();
    authenticate(email: string, licenseKey: string): Promise<License>;
    checkLicenseAvailability(): Promise<EarlyAdopterStats>;
    purchaseLicense(email: string, paymentToken: string): Promise<{
        licenseKey: string;
        license: License;
    }>;
    syncMemoryToCloud(projectId: string, memoryData: any): Promise<void>;
    getCloudMemory(projectId: string): Promise<any>;
    validateExecution(code: string, language: string, projectContext: any): Promise<any>;
    validateUsage(operation: string, email: string, licenseKey: string): Promise<{
        success: boolean;
        remaining: number;
        limit: number;
        tier: string;
    }>;
    reportUsage(action: string, metadata?: any): Promise<void>;
    private makeRequest;
    private encryptMemoryData;
    private decryptMemoryData;
    private encryptCode;
    private getCliVersion;
}
export declare const firebaseService: FirebaseService;
//# sourceMappingURL=FirebaseService.d.ts.map