"use strict";
/**
 * Licensing and Subscription Management
 * (For future cloud features)
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.licenseManager = exports.LicenseManager = void 0;
const fs = __importStar(require("fs-extra"));
const path = __importStar(require("path"));
const os = __importStar(require("os"));
class LicenseManager {
    constructor() {
        this.configPath = path.join(os.homedir(), '.codecontext', 'license.json');
    }
    async getCurrentSubscription() {
        // Always return free tier for now (until cloud features are added)
        const defaultSubscription = {
            tier: 'free',
            features: {
                localMemory: true, // Always free
                cloudSync: false, // Pro feature (coming soon)
                teamSharing: false, // Enterprise feature
                executionEngine: false, // Pro feature (Phase 2)
                advancedAnalytics: false, // Pro feature
                apiAccess: false // Enterprise feature
            }
        };
        try {
            if (await fs.pathExists(this.configPath)) {
                const saved = await fs.readJson(this.configPath);
                return { ...defaultSubscription, ...saved };
            }
        }
        catch (error) {
            // If config is corrupted, fall back to free tier
        }
        return defaultSubscription;
    }
    async validateApiKey(apiKey) {
        // TODO: Implement server-side validation when cloud features are ready
        // For now, always return false (no paid features yet)
        try {
            // Future implementation:
            // const response = await fetch('https://api.codecontextpro.com/validate', {
            //   method: 'POST',
            //   headers: { 'Content-Type': 'application/json' },
            //   body: JSON.stringify({ apiKey })
            // });
            // return response.ok;
            return false; // No cloud features yet
        }
        catch (error) {
            return false;
        }
    }
    async upgradeToCloud(apiKey) {
        const isValid = await this.validateApiKey(apiKey);
        if (!isValid) {
            throw new Error('Invalid API key. Visit https://codecontextpro.com to get your key.');
        }
        // Save the validated subscription
        const subscription = {
            tier: 'pro',
            apiKey,
            features: {
                localMemory: true,
                cloudSync: true,
                teamSharing: false,
                executionEngine: true,
                advancedAnalytics: true,
                apiAccess: false
            }
        };
        await fs.ensureDir(path.dirname(this.configPath));
        await fs.writeJson(this.configPath, subscription, { spaces: 2 });
        return true;
    }
    async requireFeature(feature) {
        const subscription = await this.getCurrentSubscription();
        if (!subscription.features[feature]) {
            const upgradeMessage = this.getUpgradeMessage(feature);
            throw new Error(upgradeMessage);
        }
    }
    getUpgradeMessage(feature) {
        const messages = {
            cloudSync: 'Cloud sync requires CodeContext Pro. Visit https://codecontextpro.com to upgrade.',
            teamSharing: 'Team sharing requires CodeContext Enterprise. Contact sales@codecontextpro.com',
            executionEngine: 'Code execution requires CodeContext Pro. Visit https://codecontextpro.com to upgrade.',
            advancedAnalytics: 'Advanced analytics requires CodeContext Pro. Visit https://codecontextpro.com to upgrade.',
            apiAccess: 'API access requires CodeContext Enterprise. Contact sales@codecontextpro.com'
        };
        return messages[feature] || 'This feature requires a paid subscription.';
    }
    async showUpgradeInfo() {
        const subscription = await this.getCurrentSubscription();
        console.log(`
🧠 CodeContext Pro Subscription

Current Tier: ${subscription.tier.toUpperCase()}

Features Available:
${subscription.features.localMemory ? '✅' : '❌'} Local Memory
${subscription.features.cloudSync ? '✅' : '❌'} Cloud Sync
${subscription.features.teamSharing ? '✅' : '❌'} Team Sharing  
${subscription.features.executionEngine ? '✅' : '❌'} Code Execution Engine
${subscription.features.advancedAnalytics ? '✅' : '❌'} Advanced Analytics
${subscription.features.apiAccess ? '✅' : '❌'} API Access

${subscription.tier === 'free' ? `
💡 Upgrade to Pro for cloud sync and execution engine:
   Visit https://codecontextpro.com

💼 Need enterprise features?
   Contact sales@codecontextpro.com
` : '✨ All features unlocked!'}
    `);
    }
}
exports.LicenseManager = LicenseManager;
exports.licenseManager = new LicenseManager();
//# sourceMappingURL=licensing.js.map